==> type-json-mapper-1.2.2.tgz: package/esm/index.js <==
import { transType } from './transform';
import { getJsonProperty, hasAnyNullOrUndefined, isArray, isObject, setProperty } from './utils';
export function mapperProperty(value, typeName) {
    var metadata = {
        typeName: typeName,
        localKey: value
    };
    return setProperty(metadata);
}
export function deepMapperProperty(value, Clazz) {
    var metadata = {
        localKey: value,
        Clazz: Clazz
    };
    return setProperty(metadata);
}
export function filterMapperProperty(value, filter) {
    var metadata = {
        localKey: value,
        filter: filter
    };
    return setProperty(metadata);
}
export function deserialize(Clazz, json) {
    if (hasAnyNullOrUndefined(Clazz, json)) {
        throw new Error('(type-json-mapper)deserialize：missing Clazz or json');
    }
    if (!isObject(json)) {
        throw new Error('(type-json-mapper)deserialize：json is not a object');
    }
    var result = {};
    var instance = new Clazz();
    var keys = Object.keys(instance);
    result = instance;
    for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
        var key = keys_1[_i];
        var value = json[key];
        var metaObj = {};
        metaObj = getJsonProperty(instance, key);
        if (typeof metaObj === 'undefined') {
            metaObj = {};
        }
        var typeName = metaObj.typeName, localKey = metaObj.localKey;
        if (!['', 0, undefined].includes(localKey)) {
            value = json[localKey];
            if (typeof value !== 'undefined') {
                value = transType(value, typeName);
            }
        }
        var filter = metaObj.filter;
        if (typeof filter === 'function') {
            var tempVal = filter(value);
            if (typeof tempVal !== 'undefined') {
                value = tempVal;
            }
        }
        var childClazz = metaObj.Clazz;
        if (typeof childClazz !== 'undefined') {
            if (isObject(value)) {
                value = deserialize(childClazz, value);
            }
            if (isArray(value)) {
                value = deserializeArr(childClazz, value);
            }
        }
        result[key] = value;
    }
    return result;
}
export function deserializeArr(Clazz, list) {
    if (hasAnyNullOrUndefined(Clazz, list)) {
        throw new Error('(type-json-mapper)deserializeArr：missing Clazz or list');
    }
    return list.map(function (ele) { return deserialize(Clazz, ele); });
}

==> type-json-mapper-1.2.3.tgz: package/esm/index.js <==
import { mockByType, transType } from './lib/transform';
import { getJsonProperty, getRandomInt, hasAnyNullOrUndefined, isArray, isObject, setProperty } from './lib/utils';
var TAG = '[type-json-mapper';
export function mapperProperty(value, typeName) {
    var metadata = {
        typeName: typeName,
        localKey: value
    };
    return setProperty(metadata);
}
export function deepMapperProperty(value, Clazz) {
    var metadata = {
        localKey: value,
        Clazz: Clazz
    };
    return setProperty(metadata);
}
export function filterMapperProperty(value, filter) {
    var metadata = {
        localKey: value,
        filter: filter
    };
    return setProperty(metadata);
}
export function deserialize(Clazz, json) {
    if (hasAnyNullOrUndefined(Clazz, json)) {
        throw new Error(TAG + "/deserialize]: missing Clazz or json");
    }
    if (!isObject(json)) {
        throw new Error(TAG + "/deserialize]: json is not a object");
    }
    var result = {};
    var instance = new Clazz();
    var keys = Object.keys(instance);
    result = instance;
    for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
        var key = keys_1[_i];
        var value = json[key];
        var metaObj = {};
        metaObj = getJsonProperty(instance, key);
        if (typeof metaObj === 'undefined') {
            metaObj = {};
        }
        var typeName = metaObj.typeName, localKey = metaObj.localKey;
        if (!['', 0, undefined].includes(localKey)) {
            value = json[localKey];
            if (typeof value !== 'undefined') {
                value = transType(value, typeName);
            }
        }
        var filter = metaObj.filter;
        if (typeof filter === 'function') {
            var tempVal = filter(value);
            if (typeof tempVal !== 'undefined') {
                value = tempVal;
            }
        }
        var childClazz = metaObj.Clazz;
        if (typeof childClazz !== 'undefined') {
            if (isObject(value)) {
                value = deserialize(childClazz, value);
            }
            if (isArray(value)) {
                value = deserializeArr(childClazz, value);
            }
        }
        result[key] = value;
    }
    return result;
}
export function deserializeArr(Clazz, list) {
    if (hasAnyNullOrUndefined(Clazz, list)) {
        throw new Error(TAG + "/deserializeArr]: missing Clazz or list");
    }
    return list.map(function (ele) { return deserialize(Clazz, ele); });
}
export function mock(Clazz, options) {
    var result = {};
    var instance = new Clazz();
    var keys = Object.keys(instance);
    result = instance;
    var _loop_1 = function (key) {
        var _a = options.fieldLength, fieldLength = _a === void 0 ? {} : _a, _b = options.arrayFields, arrayFields = _b === void 0 ? [] : _b;
        var value = '';
        var metaObj = {};
        metaObj = getJsonProperty(instance, key);
        if (typeof metaObj === 'undefined') {
            metaObj = {};
        }
        var typeName = metaObj.typeName;
        if (typeName) {
            var length_1 = fieldLength[key] || 6;
            value = mockByType(typeName, length_1);
        }
        var filter = metaObj.filter;
        if (typeof filter === 'function') {
            var tempVal = filter(value);
            if (typeof tempVal !== 'undefined') {
                value = tempVal;
            }
        }
        var childClazz = metaObj.Clazz;
        if (typeof childClazz !== 'undefined') {
            if (arrayFields.includes(key)) {
                value = new Array(getRandomInt(1, 18)).fill(0).map(function () { return mock(childClazz, options); });
            }
            else {
                value = mock(childClazz, options);
            }
        }
        result[key] = value;
    };
    for (var _i = 0, keys_2 = keys; _i < keys_2.length; _i++) {
        var key = keys_2[_i];
        _loop_1(key);
    }
    return result;
}
